..
   Just reuse the root readme to avoid duplicating the documentation.
   Provide any documentation specific to your online documentation
   here.

.. include:: ../../README.rst

.. toctree::
   :hidden:
   :maxdepth: 3

   api/index
   changelog
